#!/bin/sh
#
# Copyright (c) 2018 Oracle and/or its affiliates. All rights reserved.
# Licensed under the Universal Permissive License v 1.0 as shown at http://oss.oracle.com/licenses/upl.

readonly KUBEDIR="$(cat /usr/local/share/kubeadm/kubeadm-ha/KUBEDIR)"
if [[ -z "${KUBEDIR}" ]]; then
	echo "[ERROR] file /usr/local/share/kubeadm/kubeadm-ha/KUBEDIR doesn't exist or empty"
	exit 1
fi

NODE=$(ls ${KUBEDIR}/kubeadm-config-* | awk -F- '{print $3}')
if [[ -z "${NODE}" ]]; then
	echo "[ERROR] ${KUBEDIR}/kubeadm-config-* file doesn't exist"
	exit 1
fi

BACKUPDIR=${1:-}
if [[ -z "${BACKUPDIR}" ]]; then
        echo "[ERROR] Please provide a backup directory"
        exit 1
fi
if [[ ! -d "${BACKUPDIR}" ]]; then
	echo "[ERROR] Directory ${BACKUPDIR} doesn't exist"
	exit 1
fi
mkdir -p ${BACKUPDIR}/backup-${NODE}
# /etc/kubernetes
cd /etc/kubernetes && tar -cpf ${BACKUPDIR}/backup-${NODE}/kubernetes-${NODE}.tar .
cd ${KUBEDIR}
# extract etcd name
ETCDNAME=$(awk -F= '/\-\-name/ {print $2}' /etc/kubernetes/manifests/etcd.yaml)
echo "${ETCDNAME}" > ${KUBEDIR}/etcdname

if [[ -f "/etc/systemd/system/kubelet.service.d/20-pod-infra-image.conf" ]]; then
	cp /etc/systemd/system/kubelet.service.d/20-pod-infra-image.conf ${KUBEDIR}/
fi

if [[ -f "/etc/sysconfig/kubelet" ]]; then
	cp /etc/sysconfig/kubelet ${KUBEDIR}/
fi

if [[ -f "/var/lib/kubelet/config.yaml" ]]; then
	cp /var/lib/kubelet/config.yaml ${KUBEDIR}/
fi

if [[ -f "/var/lib/kubelet/kubeadm-flags.env" ]]; then
        cp /var/lib/kubelet/kubeadm-flags.env ${KUBEDIR}/
fi

# since 1.13, kubelet uses file in pki dir in client-certificate in HA remote master
if [[ -d "/var/lib/kubelet/pki" ]]; then
	cp -R /var/lib/kubelet/pki ${KUBEDIR}/
fi

tar -cpf ${BACKUPDIR}/backup-${NODE}/kubeadm-${NODE}.tar .

cd /etc/keepalived && tar -cpf ${BACKUPDIR}/backup-${NODE}/keepalived-${NODE}.tar .
cd ${BACKUPDIR}/backup-${NODE}/
sha256sum kubeadm-${NODE}.tar | tee ${BACKUPDIR}/backup-${NODE}/kubeadm.sha256 > /dev/null
sha256sum kubernetes-${NODE}.tar | tee ${BACKUPDIR}/backup-${NODE}/kubernetes.sha256 > /dev/null
sha256sum keepalived-${NODE}.tar | tee ${BACKUPDIR}/backup-${NODE}/keepalived.sha256 > /dev/null

# tar the whole dir now
TIMESTAMP=$(date +"%s")
tar -cpf ${BACKUPDIR}/backup-${NODE}-${TIMESTAMP}.tar .
echo "Backup file is ${BACKUPDIR}/backup-${NODE}-${TIMESTAMP}.tar"
