#!/bin/sh
#
# Copyright (c) 2018 Oracle and/or its affiliates. All rights reserved.
# Licensed under the Universal Permissive License v 1.0 as shown at http://oss.oracle.com/licenses/upl.

readonly KUBEDIR="$(cat /usr/local/share/kubeadm/kubeadm-ha/KUBEDIR)"
if [[ -z "${KUBEDIR}" ]]; then
        echo "[ERROR] file /usr/local/share/kubeadm/kubeadm-ha/KUBEDIR doesn't exist or empty"
        exit 1
fi

BACKUPDIR=${1:-}
if [[ -z "${BACKUPDIR}" ]]; then
        echo "[ERROR] Please provide a backup directory"
        exit 1
fi

if [[ ! -d "${BACKUPDIR}" ]]; then
        echo "[ERROR] Directory ${BACKUPDIR} doesn't exist"
        exit 1
fi

TIMESTAMP=$(date +"%s")

# ETCD PART
mkdir -p ${BACKUPDIR}/etcd
cd ${BACKUPDIR}/etcd
mv /var/lib/etcd/etcd-snap.db .
sha256sum etcd-snap.db | tee etcd.sha256sum > /dev/null

tar -cpf ${BACKUPDIR}/etcd.tar .

# Combine all of the TAR files
cd ${BACKUPDIR}
tar -cpf ${BACKUPDIR}/fullbackup-${TIMESTAMP}.tar *.tar

# clean up
rm -rf backup* etcd*
echo "Backup is stored at ${BACKUPDIR}/fullbackup-${TIMESTAMP}.tar"
