#!/bin/sh -x
#
# Copyright (c) 2018 Oracle and/or its affiliates. All rights reserved.
# Licensed under the Universal Permissive License v 1.0 as shown at http://oss.oracle.com/licenses/upl.

readonly KUBEDIR="$(cat /usr/local/share/kubeadm/kubeadm-ha/KUBEDIR)"
readonly TMPDIR="/tmp/.kubeadm/tmp"
BACKUP=${1:-}
if [[ -z "${BACKUP}" ]]; then
        echo "Please provide a backup file"
        exit 1
fi

rm -rf ${TMPDIR}
mkdir -p ${TMPDIR}

cp ${BACKUP} ${TMPDIR}
cd ${TMPDIR}
tar -xf ${BACKUP}

# checksum
if ! sha256sum -c ./kubernetes.sha256 | grep OK; then
	echo "[ERROR] kubernetes backup file has checksum problem"
	exit 1
fi

if ! sha256sum -c ./kubeadm.sha256 | grep OK; then
        echo "[ERROR] kubeadm backup file has checksum problem"
        exit 1
fi

if ! sha256sum -c ./keepalived.sha256 | grep OK; then
	echo "[ERROR] keepalived backup file has checksum problem"
	exit 1
fi

# restore keepalived
mkdir -p /etc/keepalived
tar -xf ./keepalived-*.tar -C /etc/keepalived

# restore kubernetes
mkdir -p /etc/kubernetes
tar -xf ./kubernetes-*.tar -C /etc/kubernetes

# restore kubeadm meta
mkdir -p ${KUBEDIR}
rm -rf ${KUBEDIR}/*
tar -xf ./kubeadm-*.tar -C ${KUBEDIR}

if [[ -f "${KUBEDIR}/20-pod-infra-image.conf" ]]; then
	mv ${KUBEDIR}/20-pod-infra-image.conf /etc/systemd/system/kubelet.service.d/
fi

if [[ -f "${KUBEDIR}/kubelet" ]]; then
        mv ${KUBEDIR}/kubelet /etc/sysconfig/
fi

if [[ -f "${KUBEDIR}/config.yaml" ]]; then
        mv ${KUBEDIR}/config.yaml /var/lib/kubelet/
fi

# since 1.13, kubelet uses file in pki dir in client-certificate in HA remote master
if [[ -d "${KUBEDIR}/pki" ]]; then
	mkdir -p /var/lib/kubelet/pki
	cp -R ${KUBEDIR}/pki /var/lib/kubelet/
fi

if [[ -f "${KUBEDIR}/kubeadm-flags.env" ]]; then
        cp ${KUBEDIR}/kubeadm-flags.env /var/lib/kubelet/kubeadm-flags.env
fi
